@@ -3,20 +3,13 @@ BEGIN {
   $Geo::Routing::Driver::Gosmore::Route::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Geo::Routing::Driver::Gosmore::Route::VERSION = '0.06';
+  $Geo::Routing::Driver::Gosmore::Route::VERSION = '0.07';
 }
 use Any::Moose;
 use warnings FATAL => "all";
 
 with 'Geo::Routing::Role::Route';
 
-has travel_time => (
-    is            => 'ro',
-    isa           => 'Int',
-    documentation => '',
-    lazy_build    => 1,
-);
-
 sub _build_travel_time {
     my ($self) = @_;
 
